import * as React from 'react';
import { GestureResponderEvent } from 'react-native';
import { Props as IconProps } from '../Icon';
import { Props as LinearGradientProps } from '../LinearGradient';
import { Props as ScalableProps } from '../Scalable';
import { Props as TextProps } from '../Text';
export interface Props {
    /**
     * A color of the button. The default value is `primary`.
     */
    color?: 'black' | 'danger' | 'dark' | 'disabled' | 'facebook' | 'google' | 'info' | 'light' | 'primary' | 'success' | 'twitter' | 'warning' | 'white';
    /**
     * Icon props.
     */
    iconProps?: IconProps;
    /**
     * If `true`, the button is not pressable and a disabled style is applied. The default value is `false`.
     */
    isDisabled?: boolean;
    /**
     * If `true`, a loading indicator is shown instead of a text. The default value is `false`.
     */
    isLoading?: boolean;
    /**
     * A linear gradient of the button.
     */
    linearGradient?: 'danger' | 'info' | 'primary' | 'success' | 'warning';
    /**
     * LinearGradient props.
     */
    linearGradientProps?: Partial<LinearGradientProps>;
    /**
     * Called when a single tap gesture is detected.
     */
    onPress: (event: GestureResponderEvent) => void;
    /**
     * Scalable props.
     */
    scalableProps?: Partial<ScalableProps>;
    /**
     * A text of the button.
     */
    text: string;
    /**
     * Text props.
     */
    textProps?: Partial<TextProps>;
}
declare const Button: React.FunctionComponent<Props>;
export default Button;
