import * as React from 'react';
import { NativeSyntheticEvent, TextInput as RNTextInput, TextInputFocusEventData, TextInputProps as RNTextInputProps } from 'react-native';
export interface Props {
    /**
     * If `true`, an error style is applied. The default value is `false`.
     */
    hasError?: boolean;
    /**
     * If `true`, the text is not editable and a disabled style is applied. The default value is `false`.
     */
    isDisabled?: boolean;
    /**
     * Callback that is called when the text input is blurred.
     */
    onBlur?: (event: NativeSyntheticEvent<TextInputFocusEventData>) => void;
    /**
     * Callback that is called when the text input's text changes. Changed text is passed as
     * an argument to the callback handler.
     */
    onChange?: (text: string) => void;
    /**
     * Callback that is called when the text input is focused.
     */
    onFocus?: (event: NativeSyntheticEvent<TextInputFocusEventData>) => void;
    /**
     * The string that will be rendered before text input has been entered.
     */
    placeholder?: string;
    /**
     * React Native's TextInput props.
     */
    rnTextInputProps?: Partial<RNTextInputProps>;
    /**
     * A value of the input.
     */
    value?: string;
}
declare const TextInput: React.ForwardRefExoticComponent<Props & React.RefAttributes<RNTextInput>>;
export default TextInput;
